@@ -2046,10 +2046,30 @@ void MainWindow::on_actionUserGroup_triggered()
     }
 }
 
-/*! \brief Show news.txt in a dialog window. */
+/**
+ * Show news.txt in a dialog window.
+ */
 void MainWindow::on_actionNews_triggered()
 {
-    QResource resource(":/textfiles/news.txt");
+    showSimpleTextFile(":/textfiles/news.txt", tr("Release news"));
+}
+
+/**
+ * Show remote-contol.txt in a dialog window.
+ */
+void MainWindow::on_actionRemoteProtocol_triggered()
+{
+    showSimpleTextFile(":/textfiles/remote-control.txt",
+                       tr("Remote control protocol"));
+}
+
+/**
+ * Show simple text file in a window.
+ */
+void MainWindow::showSimpleTextFile(const QString &resource_path,
+                                    const QString &window_title)
+{
+    QResource resource(resource_path);
     QFile news(resource.absoluteFilePath());
 
     if (!news.open(QIODevice::ReadOnly | QIODevice::Text))
@@ -2080,7 +2100,7 @@ void MainWindow::on_actionNews_triggered()
     layout->addWidget(browser);
 
     QDialog *dialog = new QDialog(this);
-    dialog->setWindowTitle(tr("Release News"));
+    dialog->setWindowTitle(window_title);
     dialog->setLayout(layout);
     dialog->resize(700, 400);
     dialog->exec();
@@ -2098,7 +2118,7 @@ void MainWindow::on_actionAbout_triggered()
 {
     QMessageBox::about(this, tr("About Gqrx"),
                        tr("<p>This is Gqrx %1</p>"
-                          "<p>Copyright (C) 2011-2014 Alexandru Csete & contributors.</p>"
+                          "<p>Copyright (C) 2011-2015 Alexandru Csete & contributors.</p>"
                           "<p>Gqrx is a software defined radio receiver powered by "
                           "<a href='http://www.gnuradio.org/'>GNU Radio</a> and the Qt toolkit. "
                           "<p>Gqrx uses the <a href='http://sdr.osmocom.org/trac/wiki/GrOsmoSDR'>GrOsmoSDR</a> "
